@@ -1,4 +1,4 @@
 from .compression_error import CompressionError
 from .parsing_error import ParsingError
 from .version_error import VersionError
-from .default_value_error import DefaultValueError
+from .default_value_error import DefaultAttributeError
