@@ -2,6 +2,7 @@ from .le import *
 
 from .base_struct import BaseStruct
 from .byte_stream import ByteStream
+from .debug_byte_stream import DebugByteStream
+from .manager import Manager
 from .parseable import Parseable
-# from .ref_list import RefList
 from .version import Version
